from uuid import UUID

from db.repositories import CategoryRepository
from .schemas import CategorySchema


class CategoryService:
    category_repository = CategoryRepository()

    async def get_category_list(self, **kwargs):
        categories = await self.category_repository.get_list(**kwargs)
        return [CategorySchema.model_validate(category) for category in categories]

    async def get_category(self, id: UUID):
        category = await self.category_repository.get(id)
        return CategorySchema.model_validate(category)

    async def create_category(self, **kwargs):
        category = await self.category_repository.create(**kwargs)
        return CategorySchema.model_validate(category)

    async def update_category(self, id: UUID, **kwargs):
        category = await self.category_repository.update(id, **kwargs)
        return CategorySchema.model_validate(category)

    async def delete_category(self, id: UUID):
        return await self.category_repository.delete(id)
