from uuid import UUID

from db.repositories import UserRepository
from .schemas import UserSchema


class UserService:
    user_repository = UserRepository()

    async def get_user_list(self, **kwargs):
        users = await self.user_repository.get_list(**kwargs)
        return [UserSchema.model_validate(user) for user in users]

    async def get_user(self, id: UUID):
        user = await self.user_repository.get(id)
        return UserSchema.model_validate(user)

    async def create_user(self, **kwargs):
        user = await self.user_repository.create(**kwargs)
        return UserSchema.model_validate(user)

    async def update_user(self, id: UUID, **kwargs):
        user = await self.user_repository.update(id, **kwargs)
        return UserSchema.model_validate(user)

    async def delete_user(self, id: UUID):
        return await self.user_repository.delete(id)
